@@ -6,10 +6,9 @@ pub(crate) mod btree;
 pub(crate) mod rrb;
 
 pub(crate) mod chunk {
-  use crate::config::VectorChunkSize;
-  use sized_chunks as sc;
-  use typenum::Unsigned;
+  use crate::config::VECTOR_CHUNK_SIZE;
+  use sp_sized_chunks as sc;
 
-  pub(crate) type Chunk<A> = sc::sized_chunk::Chunk<A, VectorChunkSize>;
-  pub(crate) const CHUNK_SIZE: usize = VectorChunkSize::USIZE;
+  pub(crate) type Chunk<A> = sc::sized_chunk::Chunk<A, VECTOR_CHUNK_SIZE>;
+  pub(crate) const CHUNK_SIZE: usize = VECTOR_CHUNK_SIZE;
 }
